"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTestFile = void 0;
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const runner_js_1 = require("../helpers/runner.js");
const indentation_js_1 = require("../helpers/indentation.js");
const format_js_1 = require("../helpers/format.js");
const logs_js_1 = require("../helpers/logs.js");
const runTestFile = (filePath, configs) => new Promise((resolve) => {
    let output = '';
    const showLogs = !(0, logs_js_1.isQuiet)(configs);
    const showSuccess = (0, logs_js_1.showSuccesses)(configs);
    const showFailure = (0, logs_js_1.showFailures)(configs);
    const log = () => console.log(`${indentation_js_1.indentation.stdio}${output === null || output === void 0 ? void 0 : output.trim()}`);
    const fileRelative = path_1.default.relative(process.cwd(), filePath);
    showLogs &&
        console.log(`${indentation_js_1.indentation.test}${format_js_1.format.info('→')} ${fileRelative}`);
    const child = (0, child_process_1.spawn)((0, runner_js_1.runner)(filePath), [filePath], {
        stdio: ['inherit', 'pipe', 'pipe'],
        env: process.env,
    });
    child.stdout.on('data', (data) => {
        output += data.toString();
    });
    child.stderr.on('data', (data) => {
        output += data.toString();
    });
    child.on('close', (code) => {
        if (showLogs &&
            ((code === 0 && showSuccess) || (code !== 0 && showFailure)))
            log();
        resolve(code === 0);
    });
    child.on('error', (err) => {
        console.log(`Failed to start test: ${filePath}`, err);
        resolve(false);
    });
});
exports.runTestFile = runTestFile;
