"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTestsParallel = exports.runTests = void 0;
const path_1 = __importDefault(require("path"));
const os_1 = require("os");
const runner_js_1 = require("../helpers/runner.js");
const indentation_js_1 = require("../helpers/indentation.js");
const getFiles_js_1 = require("../helpers/getFiles.js");
const hr_js_1 = require("../helpers/hr.js");
const format_js_1 = require("../helpers/format.js");
const runTestFile_js_1 = require("./runTestFile.js");
const logs_js_1 = require("../helpers/logs.js");
const runTests = (dir, configs) => __awaiter(void 0, void 0, void 0, function* () {
    const cwd = process.cwd();
    const testDir = path_1.default.join(cwd, dir);
    const currentDir = path_1.default.relative(cwd, testDir);
    const files = (0, getFiles_js_1.getFiles)(testDir, undefined, configs);
    const totalTests = files.length;
    const showLogs = !(0, logs_js_1.isQuiet)(configs);
    let passed = true;
    if (showLogs) {
        (0, hr_js_1.hr)();
        console.log(`${format_js_1.format.bold('Directory:')} ${format_js_1.format.underline(currentDir)}${os_1.EOL}`);
    }
    for (let i = 0; i < files.length; i++) {
        const filePath = files[i];
        const fileRelative = path_1.default.relative(cwd, filePath);
        const testPassed = yield (0, runTestFile_js_1.runTestFile)(filePath, configs);
        const testNumber = i + 1;
        const counter = format_js_1.format.counter(testNumber, totalTests);
        const command = `${(0, runner_js_1.runner)(fileRelative)} ${fileRelative}`;
        const nextLine = i + 1 !== files.length ? os_1.EOL : '';
        const log = `${counter}/${totalTests} ${command}${nextLine}`;
        if (testPassed) {
            showLogs &&
                console.log(`${indentation_js_1.indentation.test}${format_js_1.format.success('✔')} ${log}`);
        }
        else {
            showLogs && console.log(`${indentation_js_1.indentation.test}${format_js_1.format.fail('✖')} ${log}`);
            passed = false;
        }
    }
    return passed;
});
exports.runTests = runTests;
const runTestsParallel = (dir, configs) => {
    const cwd = process.cwd();
    const testDir = path_1.default.join(cwd, dir);
    const files = (0, getFiles_js_1.getFiles)(testDir, undefined, configs);
    const showLogs = !(0, logs_js_1.isQuiet)(configs);
    let passed = true;
    return new Promise((resolve) => {
        for (let i = 0; i < files.length; i++) {
            const filePath = files[i];
            const fileRelative = path_1.default.relative(cwd, filePath);
            (0, runTestFile_js_1.runTestFile)(filePath, configs).then((testPassed) => {
                const command = `${(0, runner_js_1.runner)(fileRelative)} ${fileRelative}`;
                const log = command;
                if (testPassed) {
                    showLogs &&
                        console.log(`${indentation_js_1.indentation.test}${format_js_1.format.success('✔')} ${log}`);
                }
                else {
                    showLogs &&
                        console.log(`${indentation_js_1.indentation.test}${format_js_1.format.fail('✖')} ${log}`);
                    passed = false;
                }
            });
            resolve(passed);
        }
    });
};
exports.runTestsParallel = runTestsParallel;
